@ECHO OFF
:: Batch file for creating color streams from WAV files.
::
:: Input values:
:: %1 - Source WAV file
:: %2 - Image file to output (will overwrite)
::
:: Set the following values according to your system!
:: Use absolute paths, or use %~dp0% for path relative to this batch 
:: file.

SET lame_path=%~dp0%lame3.98.2\lame.exe
SET arss_path=%~dp0%arss0.2.3\arss.exe
SET gimp_path=C:\Program Files\GIMP-2.0\bin\gimp-2.6.exe


:: Check that dependency programs exist.
IF NOT EXIST "%lame_path%" GOTO error_lame_dne
IF NOT EXIST "%arss_path%" GOTO error_arss_dne
IF NOT EXIST "%gimp_path%" GOTO error_gimp_dne
IF NOT EXIST %1% GOTO error_input_dne

:: Get temp wav file.
SET temp_wav_file=%TEMP%\colorstream_temp_wav.wav

:: Get temp spectrogram file (+ format GIMP batch parameter format.  
:: i.e. backslashes to slashes)
SET temp_spect_file=%TEMP%\colorstream_temp_spectrogram.bmp
SET temp_spect_file_gimp=%temp_spect_file:\=/%

:: Get colormap file from the dir of this batch file.
SET colormap_file_gimp=%~dp0%colormap_spectrum_rgb.png
SET colormap_file_gimp=%colormap_file_gimp:\=/%

:: Get output file in GIMP batch parameter format.
SET output_file_gimp=%2
SET output_file_gimp=%output_file_gimp:\=/%


:: Generate clean wav file from wav or mp3.
ECHO.
ECHO Generating WAV...
"%lame_path%" --decode %1 %temp_wav_file%

:: Generate spectrogram.
ECHO.
ECHO Generating spectrogram...
"%arss_path%" --quiet -min 25 -max 10000 --height 128 --pps 200 --log-base 1.4 --brightness 3 "%temp_wav_file%" "%temp_spect_file%"

:: Generate color stip from temp spectrogram.
ECHO Generating color strip...
"%gimp_path%" -i -d -f -b "(ColorStripFromSpectrogram1-2 \"%temp_spect_file_gimp%\" \"%colormap_file_gimp%\" \"%output_file_gimp%\")" -b "(gimp-quit 0)"

:: Cleanup temporary file
ECHO.
DEL %temp_spect_file%
DEL %temp_wav_file%



GOTO end

:error_lame_dne
ECHO Cannot find Lame executable (must manually edit the batch file).  Exiting.
GOTO end

:error_arss_dne
ECHO Cannot find ARSS executable (must manually edit the batch file).  Exiting.
GOTO end

:error_gimp_dne
ECHO Cannot find Gimp executable (must manually edit the batch file).  Exiting.
GOTO end

:error_input_dne
ECHO Cannot find input sound file.  Exiting.
GOTO end

:error_mask_dne
ECHO Cannot find mask file mask_rgb.xcf.  Exiting.
GOTO end

:end
